@@ -5,7 +5,7 @@ AnyEvent::Impl::Event - AnyEvent adaptor for Event
 =head1 SYNOPSIS
 
    use AnyEvent;
-   use EV;
+   use Event;
   
    # this module gets loaded automatically as required
 
@@ -15,6 +15,9 @@ This module provides transparent support for AnyEvent. You don't have to
 do anything to make Event work with AnyEvent except by loading Event before
 creating the first AnyEvent watcher.
 
+The event module is reasonably efficient and generally works correctly
+even with many watchers.
+
 =cut
 
 package AnyEvent::Impl::Event;
@@ -24,7 +27,7 @@ use strict;
 
 use AnyEvent ();
 
-use Event ();
+use Event qw(time); # we have to important something to make Event use Time::HiRes
 
 sub io {
    my ($class, %arg) = @_;
@@ -35,7 +38,7 @@ sub io {
 
 sub timer {
    my ($class, %arg) = @_;
-   bless \Event->timer (%arg), $class
+   bless \Event->timer (%arg, repeat => $arg{interval}), $class
 }
 
 sub signal {
